@@ -273,11 +273,17 @@ class ImplicitEndpoint:
         view_type = view_type.upper()
         if view_type == 'API' and request.method == 'POST':
             data = request.get_json()
+            #if self.request.headers['Origin'] == 'http://localhost:3000/':
+                # set and get as
             response = []
             for call in data:
                 if "name" in call and call['name'] in self._functions:
-                    response.append(
-                        self._functions[call['name']]['ref'](*call['params']))
+                    try:
+                        ret = self._functions[call['name']]['ref'](*call['params'])
+                    except Exception as e:
+                        response.append({"exception": e})
+                    else:
+                        response.append({"returned": ret})
                 else:
                     response.append(None)
             response_obj = make_response(json.dumps(response))
@@ -299,17 +305,29 @@ class ImplicitEndpoint:
         view_type = view_type.upper()
         if view_type == 'API' and request.method == 'POST':
             data = json.loads(request.body.decode('utf-8'))
+            is_localhost = False
+            if self.request.headers['Origin'] == 'http://localhost:3000/':
+                is_localhost = True
+                if 'Authorization' in self.request.headers:
+                    self.request.session.session_key = self.request.headers['Authorization']
             response = []
             for call in data:
                 if "name" in call and call['name'] in self._functions:
-                    response.append(
-                        self._functions[call['name']]['ref'](*call['params']))
+                    try:
+                        ret = self._functions[call['name']]['ref'](*call['params'])
+                    except Exception as e:
+                        response.append({"exception": e})
+                    else:
+                        response.append({"returned": ret})
                 else:
                     response.append(None)
-            return HttpResponse(
+            ret = HttpResponse(
                 json.dumps(response),
                 content_type='application/json; charset=utf8'
             )
+            session_id = self.request.session.session_key
+            if is_localhost and session_id:
+                ret.headers['Authorization'] = session_id
         elif view_type == 'JS':
             return HttpResponse(self.reflectJS(), content_type="text/javascript")
         else:
